pub struct OnBootConfig {
pub configs: Option<Vec<SamplingConfig>>,
pub target: Option<OnBootTargetConfig>,
/* private fields */
}Fields
configs: Option<Vec<SamplingConfig>>target: Option<OnBootTargetConfig>Trait Implementations
Sourceimpl Clone for OnBootConfig
impl Clone for OnBootConfig
Sourcefn clone(&self) -> OnBootConfig
fn clone(&self) -> OnBootConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OnBootConfig
impl Debug for OnBootConfig
Sourceimpl<D: ResourceDialect> Decode<OnBootConfig, D> for OnBootConfig
impl<D: ResourceDialect> Decode<OnBootConfig, D> for OnBootConfig
Sourceimpl Default for OnBootConfig
impl Default for OnBootConfig
Sourcefn default() -> OnBootConfig
fn default() -> OnBootConfig
Returns the “default value” for a type. Read more
Sourceimpl<D: ResourceDialect> Encode<OnBootConfig, D> for &OnBootConfig
impl<D: ResourceDialect> Encode<OnBootConfig, D> for &OnBootConfig
Sourceimpl PartialEq for OnBootConfig
impl PartialEq for OnBootConfig
Sourceimpl Serializable for OnBootConfig
impl Serializable for OnBootConfig
Sourceconst SERIALIZABLE_NAME: &'static str = "fuchsia.cpu.profiler.OnBootConfig"
const SERIALIZABLE_NAME: &'static str = "fuchsia.cpu.profiler.OnBootConfig"
The serialized name.
Sourceimpl TypeMarker for OnBootConfig
impl TypeMarker for OnBootConfig
Sourcetype Owned = OnBootConfig
type Owned = OnBootConfig
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for OnBootConfig
impl ValueTypeMarker for OnBootConfig
Sourcetype Borrowed<'a> = &'a OnBootConfig
type Borrowed<'a> = &'a OnBootConfig
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Persistable for OnBootConfig
impl StructuralPartialEq for OnBootConfig