pub struct SessionManagerAbortSessionRequest {
pub task_id: Option<u64>,
/* private fields */
}Fields
task_id: Option<u64>Trait Implementations
Sourceimpl Clone for SessionManagerAbortSessionRequest
impl Clone for SessionManagerAbortSessionRequest
Sourcefn clone(&self) -> SessionManagerAbortSessionRequest
fn clone(&self) -> SessionManagerAbortSessionRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<SessionManagerAbortSessionRequest, D> for SessionManagerAbortSessionRequest
impl<D: ResourceDialect> Decode<SessionManagerAbortSessionRequest, D> for SessionManagerAbortSessionRequest
Sourceimpl Default for SessionManagerAbortSessionRequest
impl Default for SessionManagerAbortSessionRequest
Sourcefn default() -> SessionManagerAbortSessionRequest
fn default() -> SessionManagerAbortSessionRequest
Returns the “default value” for a type. Read more
Sourceimpl<D: ResourceDialect> Encode<SessionManagerAbortSessionRequest, D> for &SessionManagerAbortSessionRequest
impl<D: ResourceDialect> Encode<SessionManagerAbortSessionRequest, D> for &SessionManagerAbortSessionRequest
Sourceimpl PartialEq for SessionManagerAbortSessionRequest
impl PartialEq for SessionManagerAbortSessionRequest
Sourcefn eq(&self, other: &SessionManagerAbortSessionRequest) -> bool
fn eq(&self, other: &SessionManagerAbortSessionRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for SessionManagerAbortSessionRequest
impl TypeMarker for SessionManagerAbortSessionRequest
Sourcetype Owned = SessionManagerAbortSessionRequest
type Owned = SessionManagerAbortSessionRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for SessionManagerAbortSessionRequest
impl ValueTypeMarker for SessionManagerAbortSessionRequest
Sourcetype Borrowed<'a> = &'a SessionManagerAbortSessionRequest
type Borrowed<'a> = &'a SessionManagerAbortSessionRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Persistable for SessionManagerAbortSessionRequest
impl StructuralPartialEq for SessionManagerAbortSessionRequest